# Risk Models & Solve Helpers

Supporting data structures used internally by the engine and exposed for
advanced usage.

## FactorModel

::: basanos.math.FactorModel

---

## MatrixBundle

::: basanos.math.MatrixBundle

---

## WarmupState

::: basanos.math.WarmupState

---

## SolveStatus

::: basanos.math.SolveStatus
